unit AutorunPlugin;

interface

uses Windows;

type
  // Common function prototype
  TPluginProc = function(Data: Pointer): integer; stdcall;
  // Parser callback function prototype
  TParseNext  = function(ParamStr: PWideChar; Param: PWideChar): integer; stdcall;

  PAutorunInterface = ^TAutorunInterface;
  TAutorunInterface = record
    nSize: integer;
    hWnd: HWND;
    pSetVarProc: Pointer;
    pSetFuncProc: Pointer;
    pParseNextProc: Pointer;
  end;

  PAutorunFuncParams = ^TAutorunFuncParams;
  TAutorunFuncParams = record
    nSize: integer;
    Param: PWideChar;
    Value: PWideChar;
    MaxLen: integer;
  end;

  PPluginFuncInfo = ^TPluginFuncInfo;
  TPluginFuncInfo = record
    nSize: integer;
    FuncName: PWideChar;
    FuncAddr: Pointer;
    Flags: integer;
  end;

  PPluginVarInfo = ^TPluginVarInfo;
  TPluginVarInfo = record
    nSize: integer;
    VarName: PWideChar;
    VarValue: PWideChar;
    Flags: integer;
  end;

const
  // Function return values (error codes)
  AU_RESULT_OK = 0;
  AU_RESULT_ERR_UNKNOWN = 1;

  // Parser function return values
  AU_PARSER_NOMOREPARAMS = 0;
  AU_PARSER_REGULARPARAM = 1;
  AU_PARSER_NAMEDPARARAM = 2;

  // Flags for set variables proc
  AU_VAR_CONSTANT = 1;

  // Flags for set functions proc
  AU_FUNC_RETURNVALUE = 1;

// Wrappers
procedure AddVar(Callback: Pointer; AName, AValue: PWideChar; AFlags: integer);
procedure AddFunc(Callback: Pointer; AName: PWideChar; AAddr: Pointer; AFlags: integer);

implementation

procedure AddVar(Callback: Pointer; AName, AValue: PWideChar; AFlags: integer);
var
  VarInfo: TPluginVarInfo;
begin
  with VarInfo do
  begin
    nSize    := SizeOf(TPluginVarInfo);
    VarName  := AName;
    VarValue := AValue;
    Flags    := AFlags;
    TPluginProc(Callback)(@VarInfo);
  end;
end;

procedure AddFunc(Callback: Pointer; AName: PWideChar; AAddr: Pointer; AFlags: integer);
var
  FuncInfo: TPluginFuncInfo;
begin
  with FuncInfo do
  begin
    nSize    := SizeOf(TPluginFuncInfo);
    FuncName := AName;
    FuncAddr := AAddr;
    Flags    := AFlags;
    TPluginProc(Callback)(@FuncInfo);
  end;
end;



end.
